==> zio-aws-route53recoverycontrolconfig_2.12-5.17.126.1-sources.jar: zio/aws/route53recoverycontrolconfig/model/UpdateControlPanelRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.{
  __stringMin1Max64PatternS,
  __stringMin1Max256PatternAZaZ09
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class UpdateControlPanelRequest(
    controlPanelArn: __stringMin1Max256PatternAZaZ09,
    controlPanelName: __stringMin1Max64PatternS
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateControlPanelRequest = {
    import UpdateControlPanelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateControlPanelRequest
      .builder()
      .controlPanelArn(
        __stringMin1Max256PatternAZaZ09.unwrap(
          controlPanelArn
        ): java.lang.String
      )
      .controlPanelName(
        __stringMin1Max64PatternS.unwrap(controlPanelName): java.lang.String
      )
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.UpdateControlPanelRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.UpdateControlPanelRequest
      .wrap(buildAwsValue())
}
object UpdateControlPanelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateControlPanelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.UpdateControlPanelRequest =
      zio.aws.route53recoverycontrolconfig.model
        .UpdateControlPanelRequest(controlPanelArn, controlPanelName)
    def controlPanelArn: __stringMin1Max256PatternAZaZ09
    def controlPanelName: __stringMin1Max64PatternS
    def getControlPanelArn: ZIO[Any, Nothing, __stringMin1Max256PatternAZaZ09] =
      ZIO.succeed(controlPanelArn)
    def getControlPanelName: ZIO[Any, Nothing, __stringMin1Max64PatternS] =
      ZIO.succeed(controlPanelName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateControlPanelRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.UpdateControlPanelRequest.ReadOnly {
    override val controlPanelArn: __stringMin1Max256PatternAZaZ09 =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__stringMin1Max256PatternAZaZ09(impl.controlPanelArn())
    override val controlPanelName: __stringMin1Max64PatternS =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__stringMin1Max64PatternS(impl.controlPanelName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateControlPanelRequest
  ): zio.aws.route53recoverycontrolconfig.model.UpdateControlPanelRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53recoverycontrolconfig_2.13-5.19.8.4-sources.jar: zio/aws/route53recoverycontrolconfig/model/UpdateControlPanelRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.{
  __stringMin1Max64PatternS,
  __stringMin1Max256PatternAZaZ09
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class UpdateControlPanelRequest(
    controlPanelArn: __stringMin1Max256PatternAZaZ09,
    controlPanelName: __stringMin1Max64PatternS
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateControlPanelRequest = {
    import UpdateControlPanelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateControlPanelRequest
      .builder()
      .controlPanelArn(controlPanelArn: java.lang.String)
      .controlPanelName(controlPanelName: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.UpdateControlPanelRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.UpdateControlPanelRequest
      .wrap(buildAwsValue())
}
object UpdateControlPanelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateControlPanelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.UpdateControlPanelRequest =
      zio.aws.route53recoverycontrolconfig.model
        .UpdateControlPanelRequest(controlPanelArn, controlPanelName)
    def controlPanelArn: __stringMin1Max256PatternAZaZ09
    def controlPanelName: __stringMin1Max64PatternS
    def getControlPanelArn: ZIO[Any, Nothing, __stringMin1Max256PatternAZaZ09] =
      ZIO.succeed(controlPanelArn)
    def getControlPanelName: ZIO[Any, Nothing, __stringMin1Max64PatternS] =
      ZIO.succeed(controlPanelName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateControlPanelRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.UpdateControlPanelRequest.ReadOnly {
    override val controlPanelArn: __stringMin1Max256PatternAZaZ09 =
      impl.controlPanelArn(): __stringMin1Max256PatternAZaZ09
    override val controlPanelName: __stringMin1Max64PatternS =
      impl.controlPanelName(): __stringMin1Max64PatternS
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateControlPanelRequest
  ): zio.aws.route53recoverycontrolconfig.model.UpdateControlPanelRequest.ReadOnly =
    new Wrapper(impl)
}
